/*
 * globals.h - global macros for USBasp
 *
 * Autor..........: Markus B. Weber
 * Description....: see title
 * Licence........: GNU GPL v2 (see Readme.txt)
 * Creation Date..: 2012-11-02
 * Last change....: 2014-03-24
 */

#ifndef __globals_h_included__
#define	__globals_h_included__

#define USBasp_tiny

/* macros for gpio functions */
#ifdef USBasp_tiny
  #define F_CPU 16500000
  #define allPortsInit PORTB= 0; DDRB= 0;
  #define ledRedOn()
  #define ledRedOff()
  #define ledGreenOn()
  #define ledGreenOff()
  #define slowClockJumper 0
  #define USBPORT_DDR DDRB
  #define USBPORT_LETTER B
  #define USBPORT_DMINUS 3
  #define USBPORT_DPLUS 4 //2
  #define	ISP_OUT   PORTB
  #define ISP_IN    PINB
  #define ISP_DDR   DDRB
  #define ISP_RST   PB5
  #define ISP_MOSI  PB0
  #define ISP_MISO  PB1
  #define ISP_SCK   PB2  //PB4
  // 2014-03-24 changed from guloprog to guloprog2 layout
  #define noHWspi
#else
  #define F_CPU 12000000L  /* 12MHz */
  #define allPortsInit PORTB= 0; PORTC= 0xfe; PORTD= 0; \
                       DDRB= 0; DDRC= 0x03; DDRD= 0; \
                       DDRD= ~(1<<2);  /* INT0*/
  #define ledRedOn()    PORTC &= ~(1 << PC1)
  #define ledRedOff()   PORTC |= (1 << PC1)
  #define ledGreenOn()  PORTC &= ~(1 << PC0)
  #define ledGreenOff() PORTC |= (1 << PC0)
  #define slowClockJumper ((PINC & (1 << PC2)) == 0)
  #define USBPORT_DDR DDRB
  #define USBPORT_LETTER B
  #define USBPORT_DMINUS 0
  #define USBPORT_DPLUS 1
  #define	ISP_OUT   PORTB
  #define ISP_IN    PINB
  #define ISP_DDR   DDRB
  #define ISP_RST   PB2
  #define ISP_MOSI  PB3
  #define ISP_MISO  PB4
  #define ISP_SCK   PB5
#endif

#ifndef __ASSEMBLER__
#define SPEEDTEST \
for(;;) { \
ledRedOn(); \
asm volatile ( \
"ldi r18,61\n" \
"t3:\n" \
"ldi r17,0\n" \
"t2:\n" \
"ldi r16,0\n" \
"t1:\n" \
"dec r16\n" \
"brne t1\n" \
"dec r17\n" \
"brne t2\n" \
"dec r18\n" \
"brne t3\n"); \
ledRedOff(); \
asm volatile ( \
"ldi r18,61\n" \
"tb3:\n" \
"ldi r17,0\n" \
"tb2:\n" \
"ldi r16,0\n" \
"tb1:\n" \
"dec r16\n" \
"brne tb1\n" \
"dec r17\n" \
"brne tb2\n" \
"dec r18\n" \
"brne tb3\n"); }
#endif
#endif /* __globals_h_included__ */

